@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2023 Jonathan Schleifer <js@nil.im>
+ * Copyright (c) 2008-2024 Jonathan Schleifer <js@nil.im>
  *
  * All rights reserved.
  *
@@ -154,7 +154,7 @@ OF_SUBCLASSING_RESTRICTED
  * @class OFAAAADNSResourceRecord \
  *	  OFDNSResourceRecord.h ObjFW/OFDNSResourceRecord.h
  *
- * @brief A class represenging a DNS resource record.
+ * @brief A class representing a DNS resource record.
  */
 OF_SUBCLASSING_RESTRICTED
 @interface OFAAAADNSResourceRecord: OFDNSResourceRecord
@@ -392,7 +392,7 @@ OF_SUBCLASSING_RESTRICTED
 @end
 
 /**
- * @class OFRPNSResourceRecord \
+ * @class OFRPDNSResourceRecord \
  *	  OFDNSResourceRecord.h ObjFW/OFDNSResourceRecord.h
  *
  * @brief A class representing an RP DNS resource record.
@@ -561,7 +561,7 @@ OF_SUBCLASSING_RESTRICTED
 
 /**
  * @brief Initializes an already allocated OFSRVDNSResourceRecord with the
- *	  specified name, class, preference, mail exchange and time to live.
+ *	  specified name, priority, weight, target, port and time to live.
  *
  * @param name The name for the resource record
  * @param priority The priority for the resource record
